<?php
namespace Dojocode_Embed;


class GetChallenge {

  public function __construct() {
    add_shortcode('embed_code_challenge', array($this, 'get_challenge_embed'));
  }

  public function get_challenge_embed($challengeID){
    $secret_key = get_option('AUTH_SECRET_KEY');
    $secret_iv = get_option('AUTH_SECRET_IV');
    $algorithm = get_option('AUTH_ALGORITHM');
    $challenge_domain_uri = get_option('CHALLENGE_DOMAIN_URI');
    $theme = get_option('THEME');
    $origin = get_site_url();

    $key = substr(hash('sha256', $secret_key), 0, 32);
    $iv = substr(hash('sha256', $secret_iv), 0, 16);

    $current_user = wp_get_current_user();
    $first_name = get_user_meta($current_user->ID, 'first_name',TRUE);
    $last_name = get_user_meta($current_user->ID, 'last_name',TRUE);

    $user_email = "$current_user->user_email";
    $username = $current_user->user_login;

    $data = array(
      'firstName' => $first_name,
      'username' => $username,
      'lastName' => $last_name,
      'email' => $user_email,
      'password' => $secret_iv
    );
    $encryptedlicenseauth = json_encode($data);

    if ($secret_key && $secret_iv && $algorithm && $challenge_domain_uri) {
      $output = openssl_encrypt($encryptedlicenseauth, $algorithm, $key, 0, $iv);
      $base_url = "$challenge_domain_uri/api/v1/oembed?";
      $query_params = array(
        "url" => $challengeID['challengeid'],
        "auth" => urlencode($output),
        "theme" => $theme
      );
      $query_string = http_build_query($query_params);
      $url = $base_url . $query_string;

      // Initialize the cURL session
      $curl = curl_init();

      // Set the URL and other options for the request
      curl_setopt($curl, CURLOPT_URL, $url);
      curl_setopt($curl, CURLOPT_HTTPHEADER, array("Origin: $origin"));
      curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);

      // Make the request and get the response
      $response = curl_exec($curl);

      // Close the cURL session
      curl_close($curl);

      $data = json_decode($response, true);
      if (isset($data['errors'])) {
        $html = '';
        foreach ($data['errors'] as $error) {
          $html .= $error["message"] . "<br>";
        }
      } else {
        $html = $data['html'];
      }
    } else {
      $errors = [];
      if(!$challenge_domain_uri) array_push($errors, "CHALLENGE_DOMAIN_URI");
      if(!$secret_key) array_push($errors, "AUTH_SECRET_KEY");
      if(!$secret_iv) array_push($errors, "AUTH_SECRET_IV");
      if(!$algorithm) array_push($errors, "AUTH_ALGORITHM");

      // Set errors array
      $args = [
        'errors' => $errors
      ];

      // Load seetings-error template
      $template_path = dirname(dirname(__FILE__)) . DIRECTORY_SEPARATOR . 'includes/settings-error.php';
      load_template($template_path, false, $args);
    }
    return $html;
  }
}